==> deepin-terminal_3.2.1.1+ds1.orig.tar.xz: deepin-terminal-3.2.1.1/CHANGELOG.md <==
<a name="3.2.1.1"></a>
## 3.2.1.1 (2019-02-25)




<a name="3.2.1"></a>
## 3.2.1 (2019-01-25)


#### Bug Fixes

*   avoid using dpkg-parsechangelog ([e249b909](https://github.com/linuxdeepin/deepin-terminal/commit/e249b909ec1d6cc3a5e1d77753b9df42f6254194))



<a name="3.2"></a>
## 3.2 (2019-01-03)


#### Others

*   merge po ([2706d53b](https://github.com/linuxdeepin/deepin-terminal/commit/2706d53b237f496b92d2aadb98dd38feafa41a5d))
*   update pot ([42229a93](https://github.com/linuxdeepin/deepin-terminal/commit/42229a93b9f72013862e176b408ee05f9ee97fc0))
*   add travis-ci build ([6a71d5a9](https://github.com/linuxdeepin/deepin-terminal/commit/6a71d5a9037802c22df37374e2e96d15d58baf75))



<a name="3.1"></a>
## 3.1 (2018-12-24)


#### Bug Fixes

*   touch on selection causing deselection ([0a96f03a](https://github.com/linuxdeepin/deepin-terminal/commit/0a96f03a00f16b5c89f1df80257140ecd1c7e26f))



<a name="3.0.12"></a>
## 3.0.12 (2018-12-06)


#### Bug Fixes

*   zssh "out of pty's" issue on debian stretch w/ vendor lib ([e2efb5dc](https://github.com/linuxdeepin/deepin-terminal/commit/e2efb5dc3e0e148ebb2639d352df34df53a89f22))



<a name="3.0.11.1"></a>
## 3.0.11.1 (2018-11-26)


#### Bug Fixes

*   Update ts file and deepin vendor support ([30b80b66](https://github.com/linuxdeepin/deepin-terminal/commit/30b80b66c71e64a6178b41bbcc59388b4b55de13))



<a name="3.0.11"></a>
## 3.0.11 (2018-11-22)

*   backport support for debian stretch ([d3ec0a0](https://github.com/linuxdeepin/deepin-terminal/commit/d3ec0a077cb621cddd7945c647d655422dcdad03))


<a name="3.0.10.2"></a>
## 3.0.10.2 (2018-11-13)


#### Bug Fixes

*   use markup text to create layout ([002dad33](https://github.com/linuxdeepin/deepin-terminal/commit/002dad330bcfb803f200481b6560b762b351d874))



<a name="3.0.10.1"></a>
## 3.0.10.1 (2018-11-12)


#### Features

*   better theme preview 'eye-candy' ([edbe56a4](https://github.com/linuxdeepin/deepin-terminal/commit/edbe56a4a723a5fad60e7f10f35070afc8ecc546))



<a name="3.0.10"></a>
## 3.0.10 (2018-11-09)


#### Bug Fixes

*   theme preview use the correct color'n'text ([fb1fec94](https://github.com/linuxdeepin/deepin-terminal/commit/fb1fec94f1ba618b6524288ddb0993e97c5cb3ef))
*   remove line above at titlebar. ([8afd630e](https://github.com/linuxdeepin/deepin-terminal/commit/8afd630e3b8bf6794247f5fc05087fbb932afa55))
*   window button hover state set to hand type. ([565e97ea](https://github.com/linuxdeepin/deepin-terminal/commit/565e97ea93ab4f6287aeeb1ec0edb9fa914db260))



## [3.0.9] - 2018-11-1
* feat: update window titlebar button style

## [3.0.8] - 2018-10-16
* fix: open_in_filemanager
* fix: handle `GLib.Error'

## [3.0.7] - 2018-10-07
* fix: github issue #74
* fix: gtk_box_pack assertion error
* refactor: remove 3rdparty/ and vapi/

## [3.0.6] - 2018-10-04
* fix: github issue #73

## [3.0.5] - 2018-09-17
* fix: missing verison info when building the deb

## [3.0.4] - 2018-09-07
* fix: unregister menu before recreate menu
* refactor: match more mono fonts

## [3.0.3] - 2018-08-19
* feat: support customized version string

## [3.0.2] - 2018-08-19
* generate version information from git
* fix: support set tab title use OSC escape sequence

<a name="3.0.1"></a>
### 3.0.1 (2018-07-20)


#### Bug Fixes

*   Adapt lintian ([748a876a](https://github.com/linuxdeepin/deepin-terminal/commit/748a876a40725005ce8e415793b343d04de2fc03))
*   add TEST_BUILD configure condition ([7d757089](https://github.com/linuxdeepin/deepin-terminal/commit/7d75708997ea45f6424d80566edd67812c7fed05))



# Change Log
This is default terminal emulation application for Deepin

## [Unreleased]

## [3.0.0] - 2018-05-14
* Add customize search engine to right menu.
* Like XShell, if user set config option 'copy_on_select' to true, terminal will copy select text to system clipboard when text is selected.
* Add github, stackoverflow, duckduckgo in default search engine.
* Add git ssh link support: mouse hover git link to copy it.
* Open current directory in file manager.
* Slow down the opacity adjust speed.
* Use DBus instead dman to start Deepin Manual, Deepin Manual just will run in flatpak runtime in the future.
* Search improvements, allow to search with enter key and previous/next buttons even after initial search panel opening, improved by avently, thanks.
* Search improvements, disabled live search, improved by avently, thanks.
* Refactory CMakeLists.txt, improved by avently, thanks.
* Add WenQuanYi in mono font whitelist, WenQuanYi's attribute is incomplete, not include spacing attribue.
* Just reset terminal when exit code match samba error code, other non-zero code (such as Ctrl + C etc) don't trigger reset terminal.
* Refactory code: move prevent event code to Widgets.SpinButton.
* Prevent scrolling event of Gtk.ComboBoxText and Gtk.SpinButton.
* Add empathy theme.
* Fixed spell of README.md, thanks wtz.
* Add miss dependences in README.md.
* Add advanced options in README.md.
* Update copyright year.
* Update translations.

## [2.9.2] - 2017-12-01
- Fixed blur background not work for 4k screen.

## [2.9.1] - 2017-11-27
- Add option 'show_highlight_frame', default set to false, it's nosie to display highlight frame everytime i select terminal window.
- Adjust about dialog font size.
- Adjust progressbar draw coordinate.

## [2.9] - 2017-11-27
- Upload file to remote server when drag file to remote terminal.
- Split terminal to login server if current terminal has login.
- Set 'NO_AT_BRIDGE' environment variable with 1 to dislable accessibility dbus warning.
- Display highlight frame when select different terminal window.
- Fixed preference dialog widget width problem when use German.
- Adjust slider button text width to make it can display ip address completely.
- Add "blur background" option in preference dialog.
- Update translations.

## [2.8] - 2017-11-23
- Drag file to remote server if terminal is login.

## [2.7.7] - 2017-11-22
- Downgrade zssh version
- Change get_ssh_script_path path to follow debian policy.
- Adjust preference dialog font attribute.

## [2.7.6] - 2017-11-09
- Buildin zssh in deepin-terminal, don't need depend zssh in linux distribution
- Fixed search text color is not correctly when terminal use light theme
- Add baidu and bing search engine in right menu

## [2.7.5] - 2017-11-06
- Synchronous translations

## [2.7] - 2017-09-11
- Add 'load_theme' option to make new terminal load theme that provide by user
- Add "New theme terminal" feature: press Ctrl + Alt + num to create new theme terminal
- Update pot file with new feature: load_theme option and new theme terminal window

## [2.6] - 2017-09-05
- Update manual content to deepin-terminal 26
- Update transifex translations
- Find a safe way to make server title will change along with server login status
- Add deepin-menu in debian dependence
- Add advanced option 'print_notify_after_script_finish', terminal will quit immediately once command execute finish when this option set as true, default is false
- Add option 'cursor auto hide', terminal cursor will autohide when type text in terminal when this option set as true, default is false
- Add rename dialog in right-click menu, to make user customize terminal title, this feature can tricked by press F2
- Set tab title with server name instead server path when login in server

==> deepin-terminal_5.0.0+ds1.orig.tar.xz: deepin-terminal-5.0.0/CHANGELOG.md <==
<a name="3.2.7"></a>
## 3.2.7 (2019-06-25)


#### Features

*   allow always hide resize grip line ([209f2338](https://github.com/linuxdeepin/deepin-terminal/commit/209f2338b3b5f40da5b260965a60124396db341e))
*   add a resize grip line for not composited user ([d34a8a5a](https://github.com/linuxdeepin/deepin-terminal/commit/d34a8a5aa00e5737e6435ff546fd15459e1713a4))
*   allow config audible bell behavior ([22874bed](https://github.com/linuxdeepin/deepin-terminal/commit/22874bed1e026be148accb6caca631c477e433c5))



<a name="3.2.6"></a>
## 3.2.6 (2019-06-11)


#### Bug Fixes

*   make special password for ssh login works. ([bb5b2736](https://github.com/linuxdeepin/deepin-terminal/commit/bb5b273658db43178d806cf7d967198fac69c9b2))



<a name="3.2.5.1"></a>
## 3.2.5.1 (2019-06-03)

*  Revert a commit which cause window size grows. (#116)


<a name="3.2.5"></a>
## 3.2.5 (2019-06-01)


#### Bug Fixes

*   terminal window drifts after toggling compositor. ([b757ef93](https://github.com/linuxdeepin/deepin-terminal/commit/b757ef93f96d0a40060a9db9bde33188c0f7186f))
*   download file opened dialog should modal parent ([fdea3be8](https://github.com/linuxdeepin/deepin-terminal/commit/fdea3be8e7f9a96d85e057a69ae480b6063bf62b))



<a name="3.2.4"></a>
## 3.2.4 (2019-05-23)


#### Bug Fixes

*   May crash when split terminal window ([882b4d8c](https://github.com/linuxdeepin/deepin-terminal/commit/882b4d8c89be6419cef18124eaf2d54f79c3dfbe))



<a name="3.2.3.1"></a>
## 3.2.3.1 (2019-05-10)


#### Bug Fixes

*   Quake window get focus on KWin ([a3e46ed0](https://github.com/linuxdeepin/deepin-terminal/commit/a3e46ed0cc034d3db56f61667f2dcd4c4ad75be3))



<a name="3.2.3"></a>
## 3.2.3 (2019-05-09)


#### Bug Fixes

*   blur under KWin wm support ([28a4438c](https://github.com/linuxdeepin/deepin-terminal/commit/28a4438cf15726eb2ae7eb8c1ab28298e27f17b2))

#### Others

*   auto pull translation files from transifex (#153) ([4de4065c](https://github.com/linuxdeepin/deepin-terminal/commit/4de4065ce0dd1525f7f95f84d53afe6d93925357))
*   correct a typo ([ba8fd083](https://github.com/linuxdeepin/deepin-terminal/commit/ba8fd0832406f69e9f829303fc3d21d076cdabc7))

#### Features

*   make "Open" menu item supporting absolution paths ([a0897d95](https://github.com/linuxdeepin/deepin-terminal/commit/a0897d95c9bbdf773651478ae33d040ea09dab12))
*   dde-menu support isScaled property ([bd4df48b](https://github.com/linuxdeepin/deepin-terminal/commit/bd4df48b4eb002f183710d002bebe623dd95271b))



<a name="3.2.2.1"></a>
## 3.2.2.1 (2019-04-12)


#### Bug Fixes

*   touchscreen support breaks line selection ([8e14fa05](https://github.com/linuxdeepin/deepin-terminal/commit/8e14fa054583edf3cfcdd4479b331c02da8ed35e))



<a name="3.2.2"></a>
## 3.2.2 (2019-04-10)


#### Others

*   auto pull translation files from transifex ([1b73d534](https://github.com/linuxdeepin/deepin-terminal/commit/1b73d534866937a469e4c99b70eccc6830b644f4))
*   correct a typo ([0f3e0d13](https://github.com/linuxdeepin/deepin-terminal/commit/0f3e0d13987fd08bb75846fa62d63d9cc80eda48))
*   translation update. (#138) ([3f8556a4](https://github.com/linuxdeepin/deepin-terminal/commit/3f8556a4180d8fb32ed1b361db119b4b8f4bdbeb))

#### Features

*   config option for bold_is_bright (#135) ([16cf3780](https://github.com/linuxdeepin/deepin-terminal/commit/16cf3780b225baf701b6725725aaf5a836e042d1))



<a name="3.2.1.2"></a>
## 3.2.1.2 (2019-03-28)


#### Bug Fixes

*   fix: Take `QT_FONT_DPI` into consideration. ([700286c](https://github.com/linuxdeepin/deepin-terminal/commit/700286cd3d0b090effe744c0788b50d9c87f457c))

#### Others

*   auto pull translation files from transifex ([634e4a0d](https://github.com/linuxdeepin/deepin-terminal/commit/634e4a0d40bb21ff85176de98f5a03eb51fe726a))



<a name="3.2.1.1"></a>
## 3.2.1.1 (2019-02-25)




<a name="3.2.1"></a>
## 3.2.1 (2019-01-25)


#### Bug Fixes

*   avoid using dpkg-parsechangelog ([e249b909](https://github.com/linuxdeepin/deepin-terminal/commit/e249b909ec1d6cc3a5e1d77753b9df42f6254194))



<a name="3.2"></a>
## 3.2 (2019-01-03)


#### Others

*   merge po ([2706d53b](https://github.com/linuxdeepin/deepin-terminal/commit/2706d53b237f496b92d2aadb98dd38feafa41a5d))
*   update pot ([42229a93](https://github.com/linuxdeepin/deepin-terminal/commit/42229a93b9f72013862e176b408ee05f9ee97fc0))
*   add travis-ci build ([6a71d5a9](https://github.com/linuxdeepin/deepin-terminal/commit/6a71d5a9037802c22df37374e2e96d15d58baf75))



<a name="3.1"></a>
## 3.1 (2018-12-24)


#### Bug Fixes

*   touch on selection causing deselection ([0a96f03a](https://github.com/linuxdeepin/deepin-terminal/commit/0a96f03a00f16b5c89f1df80257140ecd1c7e26f))



<a name="3.0.12"></a>
## 3.0.12 (2018-12-06)


#### Bug Fixes

*   zssh "out of pty's" issue on debian stretch w/ vendor lib ([e2efb5dc](https://github.com/linuxdeepin/deepin-terminal/commit/e2efb5dc3e0e148ebb2639d352df34df53a89f22))



<a name="3.0.11.1"></a>
## 3.0.11.1 (2018-11-26)


#### Bug Fixes

*   Update ts file and deepin vendor support ([30b80b66](https://github.com/linuxdeepin/deepin-terminal/commit/30b80b66c71e64a6178b41bbcc59388b4b55de13))



<a name="3.0.11"></a>
## 3.0.11 (2018-11-22)

*   backport support for debian stretch ([d3ec0a0](https://github.com/linuxdeepin/deepin-terminal/commit/d3ec0a077cb621cddd7945c647d655422dcdad03))


<a name="3.0.10.2"></a>
## 3.0.10.2 (2018-11-13)


#### Bug Fixes

*   use markup text to create layout ([002dad33](https://github.com/linuxdeepin/deepin-terminal/commit/002dad330bcfb803f200481b6560b762b351d874))



<a name="3.0.10.1"></a>
## 3.0.10.1 (2018-11-12)


#### Features

*   better theme preview 'eye-candy' ([edbe56a4](https://github.com/linuxdeepin/deepin-terminal/commit/edbe56a4a723a5fad60e7f10f35070afc8ecc546))



<a name="3.0.10"></a>
## 3.0.10 (2018-11-09)


#### Bug Fixes

*   theme preview use the correct color'n'text ([fb1fec94](https://github.com/linuxdeepin/deepin-terminal/commit/fb1fec94f1ba618b6524288ddb0993e97c5cb3ef))
*   remove line above at titlebar. ([8afd630e](https://github.com/linuxdeepin/deepin-terminal/commit/8afd630e3b8bf6794247f5fc05087fbb932afa55))
*   window button hover state set to hand type. ([565e97ea](https://github.com/linuxdeepin/deepin-terminal/commit/565e97ea93ab4f6287aeeb1ec0edb9fa914db260))



## [3.0.9] - 2018-11-1
* feat: update window titlebar button style

## [3.0.8] - 2018-10-16
* fix: open_in_filemanager
* fix: handle `GLib.Error'

## [3.0.7] - 2018-10-07
* fix: github issue #74
* fix: gtk_box_pack assertion error
* refactor: remove 3rdparty/ and vapi/

## [3.0.6] - 2018-10-04
* fix: github issue #73

## [3.0.5] - 2018-09-17
* fix: missing verison info when building the deb

## [3.0.4] - 2018-09-07
* fix: unregister menu before recreate menu
* refactor: match more mono fonts

## [3.0.3] - 2018-08-19
* feat: support customized version string

## [3.0.2] - 2018-08-19
* generate version information from git
* fix: support set tab title use OSC escape sequence

<a name="3.0.1"></a>
### 3.0.1 (2018-07-20)


#### Bug Fixes

*   Adapt lintian ([748a876a](https://github.com/linuxdeepin/deepin-terminal/commit/748a876a40725005ce8e415793b343d04de2fc03))
*   add TEST_BUILD configure condition ([7d757089](https://github.com/linuxdeepin/deepin-terminal/commit/7d75708997ea45f6424d80566edd67812c7fed05))



# Change Log
This is default terminal emulation application for Deepin

## [Unreleased]

## [3.0.0] - 2018-05-14
* Add customize search engine to right menu.
* Like XShell, if user set config option 'copy_on_select' to true, terminal will copy select text to system clipboard when text is selected.
* Add github, stackoverflow, duckduckgo in default search engine.
* Add git ssh link support: mouse hover git link to copy it.
* Open current directory in file manager.
* Slow down the opacity adjust speed.
* Use DBus instead dman to start Deepin Manual, Deepin Manual just will run in flatpak runtime in the future.
* Search improvements, allow to search with enter key and previous/next buttons even after initial search panel opening, improved by avently, thanks.
* Search improvements, disabled live search, improved by avently, thanks.
* Refactory CMakeLists.txt, improved by avently, thanks.
* Add WenQuanYi in mono font whitelist, WenQuanYi's attribute is incomplete, not include spacing attribue.
* Just reset terminal when exit code match samba error code, other non-zero code (such as Ctrl + C etc) don't trigger reset terminal.
* Refactory code: move prevent event code to Widgets.SpinButton.
* Prevent scrolling event of Gtk.ComboBoxText and Gtk.SpinButton.
* Add empathy theme.
* Fixed spell of README.md, thanks wtz.
* Add miss dependences in README.md.
* Add advanced options in README.md.
* Update copyright year.
* Update translations.

## [2.9.2] - 2017-12-01
- Fixed blur background not work for 4k screen.

## [2.9.1] - 2017-11-27
- Add option 'show_highlight_frame', default set to false, it's nosie to display highlight frame everytime i select terminal window.
- Adjust about dialog font size.
- Adjust progressbar draw coordinate.

## [2.9] - 2017-11-27
- Upload file to remote server when drag file to remote terminal.
- Split terminal to login server if current terminal has login.
- Set 'NO_AT_BRIDGE' environment variable with 1 to dislable accessibility dbus warning.
- Display highlight frame when select different terminal window.
- Fixed preference dialog widget width problem when use German.
- Adjust slider button text width to make it can display ip address completely.
- Add "blur background" option in preference dialog.
- Update translations.

## [2.8] - 2017-11-23
- Drag file to remote server if terminal is login.

## [2.7.7] - 2017-11-22
- Downgrade zssh version
- Change get_ssh_script_path path to follow debian policy.
- Adjust preference dialog font attribute.

## [2.7.6] - 2017-11-09
- Buildin zssh in deepin-terminal, don't need depend zssh in linux distribution
- Fixed search text color is not correctly when terminal use light theme
- Add baidu and bing search engine in right menu

## [2.7.5] - 2017-11-06
- Synchronous translations

## [2.7] - 2017-09-11
- Add 'load_theme' option to make new terminal load theme that provide by user
- Add "New theme terminal" feature: press Ctrl + Alt + num to create new theme terminal
- Update pot file with new feature: load_theme option and new theme terminal window

## [2.6] - 2017-09-05
- Update manual content to deepin-terminal 26
- Update transifex translations
- Find a safe way to make server title will change along with server login status
- Add deepin-menu in debian dependence
- Add advanced option 'print_notify_after_script_finish', terminal will quit immediately once command execute finish when this option set as true, default is false
- Add option 'cursor auto hide', terminal cursor will autohide when type text in terminal when this option set as true, default is false
- Add rename dialog in right-click menu, to make user customize terminal title, this feature can tricked by press F2
- Set tab title with server name instead server path when login in server
